==> pemja-0.2.1.tar.gz: pemja-0.2.1/src/main/c/pemja/core/python_class/pyjiterable.c <==
// Copyright 2022 Alibaba Group Holding Limited.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "Pemja.h"

#include "java_class/JavaClass.h"

#include "python_class/PythonClass.h"


/* Creates a new PyJObject with a Java Iterable Object. */

PyObject*
JcpPyJIterable_New(JNIEnv *env, jobject iterable, jclass clazz)
{
    PyObject *self;

    self = JcpPyJObject_New(env, &PyJIterable_Type, iterable, clazz);

    return self;
}


/* Returns a PyJObject with the corresponding Java Iterator Object. */

static PyObject*
pyjiterable_iterator(PyObject* self)
{
    JNIEnv* env;
    jobject iterator;

    env = JcpThread_Get()->env;

    iterator = JavaIterable_iterator(env, ((PyJObject*) self)->object);

    return JcpPyObject_FromJObject(env, iterator);
}


PyTypeObject PyJIterable_Type = {
    PyVarObject_HEAD_INIT(NULL, 0)
    "pemja.PyJIterable",                        /* tp_name */
    sizeof(PyJObject),                          /* tp_basicsize */
    0,                                          /* tp_itemsize */
    0,                                          /* tp_dealloc */
    0,                                          /* tp_print */
    0,                                          /* tp_getattr */
    0,                                          /* tp_setattr */
    0,                                          /* tp_reserved */
    0,                                          /* tp_repr */
    0,                                          /* tp_as_number */
    0,                                          /* tp_as_sequence */
    0,                                          /* tp_as_mapping */
    0,                                          /* tp_hash */
    0,                                          /* tp_call */
    0,                                          /* tp_str */
    0,                                          /* tp_getattro */
    0,                                          /* tp_setattro */
    0,                                          /* tp_as_buffer */
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,   /* tp_flags */
    "Java Iterable Object",                     /* tp_doc */
    0,                                          /* tp_traverse */
    0,                                          /* tp_clear */
    0,                                          /* tp_richcompare */
    0,                                          /* tp_weaklistoffset */
    (getiterfunc) pyjiterable_iterator,         /* tp_iter */
    0,                                          /* tp_iternext */
    0,                                          /* tp_methods */
    0,                                          /* tp_members */
    0,                                          /* tp_getset */
    0,                                          /* tp_base */
    0,                                          /* tp_dict */
    0,                                          /* tp_descr_get */
    0,                                          /* tp_descr_set */
    0,                                          /* tp_dictoffset */
    0,                                          /* tp_init */
    0,                                          /* tp_alloc */
    0,                                          /* tp_new */
};

==> pemja-0.4.0.tar.gz: pemja-0.4.0/src/main/c/pemja/core/python_class/pyjiterable.c <==
// Copyright 2022 Alibaba Group Holding Limited.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "Pemja.h"

#include "java_class/JavaClass.h"

#include "python_class/PythonClass.h"


/* Creates a new PyJObject with a Java Iterable Object. */

PyObject*
JcpPyJIterable_New(JNIEnv *env, jobject iterable, jclass clazz)
{
    PyObject *self;

    self = JcpPyJObject_New(env, &PyJIterable_Type, iterable, clazz);

    return self;
}


/* Returns a PyJObject with the corresponding Java Iterator Object. */

static PyObject*
pyjiterable_iterator(PyObject* self)
{
    JNIEnv* env;
    jobject iterator;

    env = JcpThreadEnv_Get();

    iterator = JavaIterable_iterator(env, ((PyJObject*) self)->object);

    return JcpPyObject_FromJObject(env, iterator);
}


PyTypeObject PyJIterable_Type = {
    PyVarObject_HEAD_INIT(NULL, 0)
    "pemja.PyJIterable",                        /* tp_name */
    sizeof(PyJObject),                          /* tp_basicsize */
    0,                                          /* tp_itemsize */
    0,                                          /* tp_dealloc */
    0,                                          /* tp_print */
    0,                                          /* tp_getattr */
    0,                                          /* tp_setattr */
    0,                                          /* tp_reserved */
    0,                                          /* tp_repr */
    0,                                          /* tp_as_number */
    0,                                          /* tp_as_sequence */
    0,                                          /* tp_as_mapping */
    0,                                          /* tp_hash */
    0,                                          /* tp_call */
    0,                                          /* tp_str */
    0,                                          /* tp_getattro */
    0,                                          /* tp_setattro */
    0,                                          /* tp_as_buffer */
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,   /* tp_flags */
    "Java Iterable Object",                     /* tp_doc */
    0,                                          /* tp_traverse */
    0,                                          /* tp_clear */
    0,                                          /* tp_richcompare */
    0,                                          /* tp_weaklistoffset */
    (getiterfunc) pyjiterable_iterator,         /* tp_iter */
    0,                                          /* tp_iternext */
    0,                                          /* tp_methods */
    0,                                          /* tp_members */
    0,                                          /* tp_getset */
    0,                                          /* tp_base */
    0,                                          /* tp_dict */
    0,                                          /* tp_descr_get */
    0,                                          /* tp_descr_set */
    0,                                          /* tp_dictoffset */
    0,                                          /* tp_init */
    0,                                          /* tp_alloc */
    0,                                          /* tp_new */
};
